pub struct AckToken { /* private fields */ }Expand description
A token representing a batch of events that requires acknowledgement.
When an event batch is successfully written to a sink (or dropped intentionally by a transform), this token is triggered to notify the original source that it can commit the batch (e.g., commit Kafka offsets).
Implementations
Sourceimpl AckToken
impl AckToken
Sourcepub fn new(notifier: Arc<dyn BatchNotifier>) -> Self
pub fn new(notifier: Arc<dyn BatchNotifier>) -> Self
Creates a new AckToken wrapping the given notifier.
Sourcepub fn split(self, n: usize) -> Vec<AckToken>
pub fn split(self, n: usize) -> Vec<AckToken>
Splits this token into n tokens.
The underlying notifier will only be called after all n tokens have been acknowledged.
This is used by the Fanout mechanism to ensure all downstream components have processed
the batch before acknowledging it to the source.
If n is 0, the original token is effectively acknowledged immediately.
If n is 1, it returns itself.
Sourcepub fn ack(self)
pub fn ack(self)
Acknowledges the batch.
Only when all split tokens have been acknowledged will the underlying notifier be triggered.
Sourcepub fn is_acknowledged(&self) -> bool
pub fn is_acknowledged(&self) -> bool
Returns true if this token has been fully acknowledged.