BatchNotifier

Trait BatchNotifier 

pub trait BatchNotifier:
    Send
    + Sync
    + Debug {
    // Required method
    fn on_ack(&self);
}
A trait implemented by sources to receive acknowledgement notifications.

Required Methods

fn on_ack(&self)

Called when the batch associated with this notifier has been fully processed.

Implementors