pub struct ShutdownCoordinator { /* private fields */ }Expand description
Coordinates the shutdown of multiple components.
Implementations
Sourceimpl ShutdownCoordinator
impl ShutdownCoordinator
Sourcepub fn register(&self) -> ShutdownSignal
pub fn register(&self) -> ShutdownSignal
Register a new component to be managed by this coordinator.
Returns a ShutdownSignal that the component should hold and listen to.
Sourcepub fn broadcast(&self, reason: ShutdownReason)
pub fn broadcast(&self, reason: ShutdownReason)
Broadcast a shutdown signal to all registered components.