pub struct ShutdownSignal { /* private fields */ }Expand description
A handle held by a component that can be used to listen for shutdown requests.
Implementations
Sourceimpl ShutdownSignal
impl ShutdownSignal
Sourcepub async fn recv(&mut self) -> Option<ShutdownReason>
pub async fn recv(&mut self) -> Option<ShutdownReason>
Wait for a shutdown signal.
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Returns true if a shutdown signal has been received.